( cd usr/lib ; rm -rf libphysfs-1.0.so.0 )
( cd usr/lib ; ln -sf libphysfs-1.0.so.0.0.0 libphysfs-1.0.so.0 )
( cd usr/lib ; rm -rf libphysfs.so )
( cd usr/lib ; ln -sf libphysfs-1.0.so.0.0.0 libphysfs.so )
